@@ -4,12 +4,12 @@ import posixpath
 import re
 import subprocess
 import sys
-from typing import Any, Optional
+from typing import Any, List, Optional
 
 from pycomplete.templates import SUPPORTED_SHELLS, TEMPLATES
 from pycomplete.getters import GETTERS, NotSupportedError
 
-__version__ = "0.2.0"
+__version__ = "0.3.1"
 
 
 class Completer:
@@ -28,7 +28,7 @@ class Completer:
     Then save the result into a file that is read by the shell's autocomplete engine.
     """
 
-    def __init__(self, cli: Any) -> None:
+    def __init__(self, cli: Any, prog: Optional[List[str]] = None) -> None:
         for getter in GETTERS:
             try:
                 self.getter = getter(cli)
@@ -43,6 +43,9 @@ class Completer:
                 "framework. Please make sure you install pycomplete in the same "
                 "environment as the target CLI app."
             )
+        if prog is None:
+            prog = [os.path.basename(posixpath.realpath(sys.argv[0]))]
+        self.prog = prog
 
     def render(self, shell: Optional[str] = None) -> str:
         if shell is None:
@@ -56,10 +59,9 @@ class Completer:
     def render_bash(self) -> str:
         template = TEMPLATES["bash"]
 
-        script_path = posixpath.realpath(sys.argv[0])
-        script_name = os.path.basename(script_path)
-        aliases = [script_name, script_path]
-
+        script_path = os.path.realpath(sys.argv[0])
+        script_name = self.prog[0]
+        aliases = self.prog
         function = self._generate_function_name(script_name, script_path)
 
         commands = []
@@ -110,7 +112,7 @@ class Completer:
                 "coms": " ".join(commands),
                 "command_list": "\n".join(command_list),
                 "compdefs": compdefs,
-                "version": __version__
+                "version": __version__,
             }
         )
 
@@ -120,8 +122,7 @@ class Completer:
         template = TEMPLATES["zsh"]
 
         script_path = posixpath.realpath(sys.argv[0])
-        script_name = os.path.basename(script_path)
-        aliases = [script_path]
+        script_name, *aliases = self.prog
 
         function = self._generate_function_name(script_name, script_path)
 
@@ -183,7 +184,7 @@ class Completer:
                 "coms": " ".join(sorted(commands_descriptions)),
                 "command_list": "\n".join(command_list),
                 "compdefs": compdefs,
-                "version": __version__
+                "version": __version__,
             }
         )
 
@@ -193,7 +194,7 @@ class Completer:
         template = TEMPLATES["fish"]
 
         script_path = posixpath.realpath(sys.argv[0])
-        script_name = os.path.basename(script_path)
+        script_name = self.prog[0]
 
         function = self._generate_function_name(script_name, script_path)
 
@@ -271,7 +272,7 @@ class Completer:
                 "opts": "\n".join(opts),
                 "cmds": "\n".join(cmds),
                 "cmds_opts": "\n".join(cmds_opts),
-                "version": __version__
+                "version": __version__,
             }
         )
 
@@ -281,7 +282,8 @@ class Completer:
         template = TEMPLATES["powershell"]
 
         script_path = posixpath.realpath(sys.argv[0])
-        script_name = os.path.basename(script_path)
+        script_name = self.prog[0]
+        aliases = self.prog
 
         function = self._generate_function_name(script_name, script_path)
 
@@ -300,21 +302,22 @@ class Completer:
 
             commands_options[name] = command_options
 
-        opts = ", ".join(f'"{option}"' for option in global_options)
-        coms = ", ".join(f'"{cmd}"' for cmd in commands)
+        opts = ", ".join(f'"{option}"' for option in sorted(global_options))
+        coms = ", ".join(f'"{cmd}"' for cmd in sorted(commands))
         command_list = []
         for name, options in commands_options.items():
-            cmd_opts = ", ".join(f'"{option}"' for option in options)
+            cmd_opts = ", ".join(f'"{option}"' for option in sorted(options))
             command_list.append(f'                "{name}" {{ $opts = @({cmd_opts}) }}')
 
         return template.safe_substitute(
             {
                 "script_name": script_name,
                 "function": function,
+                "aliases": ", ".join(f'"{name}"' for name in aliases),
                 "opts": opts,
                 "coms": coms,
                 "command_list": "\n".join(command_list),
-                "version": __version__
+                "version": __version__,
             }
         )
 
